﻿//
// ConsoleCSharp
//
// Copyright (c) 2016 http://www.curict.com
// This software is released under the MIT License, see LICENSE.txt.
//

namespace ConsoleCSharp
{
    public class FileUtil
    {
        /// <summary>
        /// パスが正しいかチェックする
        /// </summary>
        /// <param name="path">ファイルパス</param>
        /// <param name="isFileName">ファイル名の場合true, パスの場合false</param>
        /// <returns>True:正しいパス</returns>
        public static bool IsSafePath(string path, bool isFileName)
        {
            if (string.IsNullOrEmpty(path))
            {
                // null か、空文字列は不正とする
                return false;
            }

            // 使えない文字があるかチェック
            char[] invalidChars;
            if (isFileName)
            {
                invalidChars = System.IO.Path.GetInvalidFileNameChars();
            }
            else
            {
                invalidChars = System.IO.Path.GetInvalidPathChars();
            }
            if (path.IndexOfAny(invalidChars) >= 0)
            {
                // 使えない文字がある
                return false;
            }

            // 使えないファイル名を含んでいないかチェック
            if (System.Text.RegularExpressions.Regex.IsMatch(path
                                           , @"(^|\\|/)(CON|PRN|AUX|NUL|CLOCK\$|COM[0-9]|LPT[0-9])(\.|\\|/|$)"
                                           , System.Text.RegularExpressions.RegexOptions.IgnoreCase))
            {
                // 使えないファイル名がある
                return false;
            }
            return true;
        }
    }
}
